@@ -381,6 +381,7 @@ typedef struct janus_videocall_session {
 	janus_rtp_switching_context context;
 	uint32_t ssrc[3];		/* Only needed in case VP8 (or H.264) simulcasting is involved */
 	char *rid[3];			/* Only needed if simulcasting is rid-based */
+	janus_mutex rid_mutex;	/* Mutex to protect access to the rid array */
 	janus_rtp_simulcasting_context sim_context;
 	janus_vp8_simulcast_context vp8_context;
 	janus_recorder *arc;	/* The Janus recorder instance for this user's audio, if enabled */
@@ -413,6 +414,9 @@ static void janus_videocall_session_free(const janus_refcount *session_ref) {
 	janus_refcount_decrease(&session->handle->ref);
 	/* This session can be destroyed, free all the resources */
 	g_free(session->username);
+	janus_mutex_destroy(&session->rid_mutex);
+	janus_mutex_destroy(&session->rec_mutex);
+	janus_rtp_simulcasting_cleanup(NULL, NULL, session->rid, NULL);
 	g_free(session);
 }
 
@@ -597,6 +601,7 @@ void janus_videocall_create_session(janus_plugin_session *handle, int *error) {
 	janus_vp8_simulcast_context_reset(&session->vp8_context);
 	janus_mutex_init(&session->mutex);
 	janus_mutex_init(&session->rec_mutex);
+	janus_mutex_init(&session->rid_mutex);
 	g_atomic_int_set(&session->incall, 0);
 	g_atomic_int_set(&session->hangingup, 0);
 	g_atomic_int_set(&session->destroyed, 0);
@@ -773,7 +778,7 @@ void janus_videocall_incoming_rtp(janus_plugin_session *handle, janus_plugin_rtp
 			/* Process this packet: don't relay if it's not the SSRC/layer we wanted to handle
 			 * The caveat is that the targets in OUR simulcast context are the PEER's targets */
 			gboolean relay = janus_rtp_simulcasting_context_process_rtp(&peer->sim_context,
-				buf, len, session->ssrc, session->rid, session->vcodec, &peer->context);
+				buf, len, session->ssrc, session->rid, session->vcodec, &peer->context, &session->rid_mutex);
 			/* Do we need to drop this? */
 			if(!relay)
 				return;
@@ -1038,12 +1043,7 @@ static void janus_videocall_hangup_media_internal(janus_plugin_session *handle)
 	session->bitrate = 0;
 	session->peer_bitrate = 0;
 	session->e2ee = FALSE;
-	int i=0;
-	for(i=0; i<3; i++) {
-		session->ssrc[i] = 0;
-		g_free(session->rid[i]);
-		session->rid[i] = NULL;
-	}
+	janus_rtp_simulcasting_cleanup(NULL, session->ssrc, session->rid, &session->rid_mutex);
 	janus_rtp_switching_context_reset(&session->context);
 	janus_rtp_simulcasting_context_reset(&session->sim_context);
 	janus_vp8_simulcast_context_reset(&session->vp8_context);
@@ -1303,8 +1303,12 @@ static void *janus_videocall_handler(void *data) {
 						int mindex = json_integer_value(json_object_get(s, "mindex"));
 						JANUS_LOG(LOG_VERB, "VideoCall caller (%s) is going to do simulcasting (#%d)\n", session->username, mindex);
 						int rid_ext_id = -1;
+						janus_mutex_lock(&session->rid_mutex);
+						/* Clear existing RIDs in case this is a renegotiation */
+						janus_rtp_simulcasting_cleanup(NULL, NULL, session->rid, NULL);
 						janus_rtp_simulcasting_prepare(s, &rid_ext_id, session->ssrc, session->rid);
 						session->sim_context.rid_ext_id = rid_ext_id;
+						janus_mutex_unlock(&session->rid_mutex);
 						session->sim_context.substream_target = 2;	/* Let's aim for the highest quality */
 						session->sim_context.templayer_target = 2;	/* Let's aim for all temporal layers */
 						/* FIXME We're stopping at the first item, there may be more */
@@ -1373,12 +1377,7 @@ static void *janus_videocall_handler(void *data) {
 			if(msg_simulcast && janus_get_codec_pt(msg_sdp, "vp8") > 0) {
 				JANUS_LOG(LOG_VERB, "VideoCall callee (%s) cannot do simulcast.\n", session->username);
 			} else {
-				int i=0;
-				for(i=0; i<3; i++) {
-					session->ssrc[i] = 0;
-					g_free(session->rid[0]);
-					session->rid[0] = NULL;
-				}
+				janus_rtp_simulcasting_cleanup(NULL, session->ssrc, session->rid, &session->rid_mutex);
 			}
 			/* Check which codecs we ended up using */
 			const char *acodec = NULL, *vcodec = NULL;
