@@ -27,6 +27,8 @@
 #include <glib.h>
 #include <jansson.h>
 
+#include "plugins/plugin.h"
+
 #define RTP_HEADER_SIZE	12
 
 /*! \brief RTP Header (http://tools.ietf.org/html/rfc3550#section-5.1) */
@@ -60,6 +62,7 @@ typedef struct janus_rtp_packet {
 	gint length;
 	gint64 created;
 	gint64 last_retransmit;
+	janus_plugin_rtp_extensions extensions;
 } janus_rtp_packet;
 
 /*! \brief RTP extension */
@@ -328,6 +331,14 @@ void janus_rtp_simulcasting_context_reset(janus_rtp_simulcasting_context *contex
  * @param[in] rids The list of rids to update, if any (items will be allocated) */
 void janus_rtp_simulcasting_prepare(json_t *simulcast, int *rid_ext_id, uint32_t *ssrcs, char **rids);
 
+/*! \brief Helper method to cleanup some or all of the simulcasting info
+ * (rids and/or SSRCs) we may have prepared before via janus_rtp_simulcasting_prepare
+ * @param[in] rid_ext_id The rid RTP extension ID to cleanup, if any
+ * @param[in] ssrcs The list of simulcast SSRCs to cleanup, if any
+ * @param[in] rids The list of rids to cleanup, if any (items will be freed and NULL-ed)
+ * @param[in] rid_mutex A mutex that must be acquired before cleaning up, if any */
+void janus_rtp_simulcasting_cleanup(int *rid_ext_id, uint32_t *ssrcs, char **rids, janus_mutex *rid_mutex);
+
 /*! \brief Process an RTP packet, and decide whether this should be relayed or not, updating the context accordingly
  * \note Calling this method resets the \c changed_substream , \c changed_temporal and \c need_pli
  * properties, and updates them according to the decisions made after processing the packet
@@ -338,10 +349,11 @@ void janus_rtp_simulcasting_prepare(json_t *simulcast, int *rid_ext_id, uint32_t
  * @param[in] rids The simulcast rids to refer to, if any
  * @param[in] vcodec Video codec of the RTP payload
  * @param[in] sc RTP switching context to refer to, if any (only needed for VP8 and dropping temporal layers)
+ * @param[in] rid_mutex A mutex that must be acquired before reading the rids array, if any
  * @returns TRUE if the packet should be relayed, FALSE if it should be dropped instead */
 gboolean janus_rtp_simulcasting_context_process_rtp(janus_rtp_simulcasting_context *context,
 	char *buf, int len, uint32_t *ssrcs, char **rids,
-	janus_videocodec vcodec, janus_rtp_switching_context *sc);
+	janus_videocodec vcodec, janus_rtp_switching_context *sc, janus_mutex *rid_mutex);
 ///@}
 
 /** @name Janus AV1-SVC processing methods
