@@ -31,7 +31,7 @@
 
 /* Pre-parse SDP: is this SDP valid? how many audio/video lines? any features to take into account? */
 janus_sdp *janus_sdp_preparse(void *ice_handle, const char *jsep_sdp, char *error_str, size_t errlen,
-		int *audio, int *video, int *data) {
+		janus_dtls_role *dtls_role, int *audio, int *video, int *data) {
 	if(!ice_handle || !jsep_sdp) {
 		JANUS_LOG(LOG_ERR, "  Can't preparse, invalid arguments\n");
 		return NULL;
@@ -43,6 +43,34 @@ janus_sdp *janus_sdp_preparse(void *ice_handle, const char *jsep_sdp, char *erro
 		/* Invalid SDP */
 		return NULL;
 	}
+	gboolean dtls_role_found = FALSE;
+	if(dtls_role) {
+		/* We're interested in checking which role was advertised, traverse global attributes too */
+		GList *tempA = parsed_sdp->attributes;
+		while(tempA) {
+			janus_sdp_attribute *a = (janus_sdp_attribute *)tempA->data;
+			if(a->name && !strcasecmp(a->name, "setup")) {
+				if(a->value == NULL) {
+					JANUS_LOG(LOG_ERR, "[%"SCNu64"] Invalid setup attribute (no value)\n", handle->handle_id);
+					janus_sdp_destroy(parsed_sdp);
+					return NULL;
+				}
+				if(!strcasecmp(a->value, "actpass")) {
+					JANUS_LOG(LOG_VERB, "[%"SCNu64"] Peer advertised 'actpass' DTLS role, we'll be a DTLS client\n", handle->handle_id);
+					*dtls_role = JANUS_DTLS_ROLE_ACTPASS;
+				} else if(!strcasecmp(a->value, "passive")) {
+					JANUS_LOG(LOG_VERB, "[%"SCNu64"] Peer advertised 'passive' DTLS role, we'll be a DTLS client\n", handle->handle_id);
+					*dtls_role = JANUS_DTLS_ROLE_SERVER;
+				} else if(!strcasecmp(a->value, "active")) {
+					JANUS_LOG(LOG_VERB, "[%"SCNu64"] Peer advertised 'active' DTLS role, we'll be a DTLS server\n", handle->handle_id);
+					*dtls_role = JANUS_DTLS_ROLE_CLIENT;
+				}
+				dtls_role_found = TRUE;
+				break;
+			}
+			tempA = tempA->next;
+		}
+	}
 	/* Look for m-lines */
 	GList *temp = parsed_sdp->m_lines;
 	while(temp) {
@@ -79,6 +107,23 @@ janus_sdp *janus_sdp_preparse(void *ice_handle, const char *jsep_sdp, char *erro
 							return NULL;
 						}
 					}
+				} else if(dtls_role && !dtls_role_found && !strcasecmp(a->name, "setup")) {
+					if(a->value == NULL) {
+						JANUS_LOG(LOG_ERR, "[%"SCNu64"] Invalid setup attribute (no value)\n", handle->handle_id);
+						janus_sdp_destroy(parsed_sdp);
+						return NULL;
+					}
+					if(!strcasecmp(a->value, "actpass")) {
+						JANUS_LOG(LOG_VERB, "[%"SCNu64"] Peer advertised 'actpass' DTLS role, we'll be a DTLS client\n", handle->handle_id);
+						*dtls_role = JANUS_DTLS_ROLE_ACTPASS;
+					} else if(!strcasecmp(a->value, "passive")) {
+						JANUS_LOG(LOG_VERB, "[%"SCNu64"] Peer advertised 'passive' DTLS role, we'll be a DTLS client\n", handle->handle_id);
+						*dtls_role = JANUS_DTLS_ROLE_SERVER;
+					} else if(!strcasecmp(a->value, "active")) {
+						JANUS_LOG(LOG_VERB, "[%"SCNu64"] Peer advertised 'active' DTLS role, we'll be a DTLS server\n", handle->handle_id);
+						*dtls_role = JANUS_DTLS_ROLE_CLIENT;
+					}
+					dtls_role_found = TRUE;
 				}
 			}
 			tempA = tempA->next;
@@ -532,7 +577,7 @@ int janus_sdp_process_remote(void *ice_handle, janus_sdp *remote_sdp, gboolean r
 						}
 					}
 				} else if(!strcasecmp(a->name, "rtpmap")) {
-					if(a->value) {
+					if(a->value && strstr(a->value, "rtx") == NULL) {
 						int ptype = atoi(a->value);
 						if(ptype > -1) {
 							char *cr = strchr(a->value, '/');
@@ -617,6 +662,24 @@ int janus_sdp_process_remote(void *ice_handle, janus_sdp *remote_sdp, gboolean r
 					medium->rtcp_ctx[2]->tb = 90000;
 				}
 			}
+			if(m->type == JANUS_SDP_VIDEO && medium->rtx_payload_types && m->ptypes) {
+				/* Check if there are new payload types that conflict with our rtx additions */
+				GList *ptypes = g_list_copy(m->ptypes), *tempP = ptypes;
+				GList *rtx_ptypes = g_hash_table_get_values(medium->rtx_payload_types);
+				while(tempP) {
+					int ptype = GPOINTER_TO_INT(tempP->data);
+					if(g_hash_table_lookup(medium->clock_rates, GINT_TO_POINTER(ptype)) &&
+							g_list_find(rtx_ptypes, GINT_TO_POINTER(ptype))) {
+						/* We have a payload type that is both a codec and rtx, get rid of it */
+						JANUS_LOG(LOG_WARN, "[%"SCNu64"] Removing duplicate payload type %d\n", handle->handle_id, ptype);
+						janus_sdp_remove_payload_type(remote_sdp, medium->mindex, ptype);
+						g_hash_table_remove(medium->clock_rates, GINT_TO_POINTER(ptype));
+					}
+					tempP = tempP->next;
+				}
+				g_list_free(ptypes);
+				g_list_free(rtx_ptypes);
+			}
 		}
 		temp = temp->next;
 	}
@@ -672,7 +735,7 @@ int janus_sdp_process_local(void *ice_handle, janus_sdp *remote_sdp, gboolean up
 		GList *tempA = m->attributes;
 		while(tempA) {
 			janus_sdp_attribute *a = (janus_sdp_attribute *)tempA->data;
-			if(a->name) {
+			if(a->name && a->value) {
 				if(!strcasecmp(a->name, "mid")) {
 					/* Found mid attribute */
 					if(strlen(a->value) > 16) {
@@ -695,6 +758,22 @@ int janus_sdp_process_local(void *ice_handle, janus_sdp *remote_sdp, gboolean up
 					m->attributes = g_list_remove_link(m->attributes, mid_attr);
 					g_list_free_full(mid_attr, (GDestroyNotify)janus_sdp_attribute_destroy);
 					continue;
+				} else if(!strcasecmp(a->name, "rtpmap")) {
+					if(a->value && strstr(a->value, "rtx") == NULL) {
+						int ptype = atoi(a->value);
+						if(ptype > -1) {
+							char *cr = strchr(a->value, '/');
+							if(cr != NULL) {
+								cr++;
+								uint32_t clock_rate = 0;
+								if(janus_string_to_uint32(cr, &clock_rate) == 0) {
+									if(medium->clock_rates == NULL)
+										medium->clock_rates = g_hash_table_new(NULL, NULL);
+									g_hash_table_insert(medium->clock_rates, GINT_TO_POINTER(ptype), GUINT_TO_POINTER(clock_rate));
+								}
+							}
+						}
+					}
 				}
 			}
 			tempA = tempA->next;
@@ -1520,7 +1599,8 @@ char *janus_sdp_merge(void *ice_handle, janus_sdp *anon, gboolean offer) {
 			if(medium->ssrc > 0) {
 				a = janus_sdp_attribute_create("ssrc", "%"SCNu32" cname:janus", medium->ssrc);
 				m->attributes = g_list_append(m->attributes, a);
-				if(m->type == JANUS_SDP_VIDEO && janus_flags_is_set(&handle->webrtc_flags, JANUS_ICE_HANDLE_WEBRTC_RFC4588_RTX)) {
+				if(medium->ssrc_rtx > 0 && m->type == JANUS_SDP_VIDEO &&
+						janus_flags_is_set(&handle->webrtc_flags, JANUS_ICE_HANDLE_WEBRTC_RFC4588_RTX)) {
 					/* Add rtx SSRC group to negotiate the RFC4588 stuff */
 					a = janus_sdp_attribute_create("ssrc", "%"SCNu32" cname:janus", medium->ssrc_rtx);
 					m->attributes = g_list_append(m->attributes, a);
